window.Gleam.initSearch([{"doc":"glyph","title":"glyph","content":"# glyph\n\nI am primarily writing this to learn Gleam + the BEAM ecosystem, though I do plan on fully implementing all features.\n\nI do not recommend using this for a &quot;real&quot; bot just yet - there&#39;s still many missing events and it is not prepared for highly available bots yet.\n\nI _do_ recommend using this if you just want to play around with it and maybe even contribute!\n\n## Roadmap\n\nJust so you have an idea of what my focus will be the next few weeks:\n- v0.1 - fully implement all gateway events &lt;-- we are here!\n- v0.2 - fully implement the REST client and its payloads (along with tests)\n- v0.3 - start working on shard management, reconnect logic, etc.\n\n[![Package Version](https://img.shields.io/hexpm/v/gliscord)](https://hex.pm/packages/glyph)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glyph/)\n\n## Add Glyph to your project\n\n```sh\ngleam add glyph\n```\n\n## Basic example usage\n\n```gleam\nimport gleam/io\nimport glyph/clients/api\nimport glyph/clients/bot\nimport glyph/models/discord\nimport envoy\nimport logging\n\npub type LogLevel {\n  Debug\n}\n\npub type Log {\n  Level\n}\n\n@external(erlang, &quot;logger&quot;, &quot;set_primary_config&quot;)\nfn set_logger_level(log: Log, level: LogLevel) -&gt; Nil\n\npub fn main() {\n  logging.configure()\n  // NOTE:  This isn&#39;t strictly necessary at all (including the associated\n  // stuff above). It&#39;s included just to show the debug logging.\n  set_logger_level(Level, Debug)\n\n  let discord_token = case envoy.get(&quot;DISCORD_TOKEN&quot;) {\n    Ok(token) -&gt; token\n    Error(_) -&gt; &quot;&quot;\n  }\n\n  io.println(&quot;DISCORD_TOKEN: &quot; &lt;&gt; discord_token)\n\n  // Create a new API client and invoke a function\n  // Note: the intention for next release is to abstract these behind helper functions in the bot client\n  // that way handlers can invoke them\n  let some_channel = &quot;1217259472096067625&quot;\n  let _ =\n    api.new(discord_token, &quot;https://github.com/grottohub/glyph&quot;, &quot;0.0.1&quot;)\n    |&gt; api.create_message(some_channel, discord.MessagePayload(&quot;I&#39;m alive!&quot;))\n\n  // Create a new bot and register its handlers\n  bot.new(discord_token, &quot;https://github.com/grottohub/glyph&quot;, &quot;0.0.1&quot;)\n  |&gt; bot.set_intents([discord.GuildMessages, discord.MessageContent])\n  |&gt; bot.on_message_create(message_create_callback)\n  |&gt; bot.initialize\n}\n\npub fn message_create_callback(\n  msg: discord.Message,\n) -&gt; Result(Nil, discord.DiscordError) {\n  logging.log(logging.Info, &quot;Got: &quot; &lt;&gt; msg.content)\n\n  Ok(Nil)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glyph&gt;.\n","url":"index.html"},{"doc":"glyph/models/discord","title":"Application","content":"pub type Application {\n  Application(\n    id: Snowflake,\n    name: String,\n    icon: Option(String),\n    description: String,\n    rpc_origins: Option(List(String)),\n    bot_public: Bool,\n    bot_require_code_grant: Bool,\n    bot: Option(Bot),\n    terms_of_service_url: Option(String),\n    privacy_policy_url: Option(String),\n    owner: Option(Owner),\n    summary: Option(String),\n    verify_key: String,\n    team: Option(Team),\n    guild_id: Option(Snowflake),\n    primary_sku_id: Option(Snowflake),\n    slug: Option(String),\n    cover_image: Option(String),\n    flags: Option(Int),\n    approximate_guild_count: Option(Int),\n    redirect_uris: Option(List(String)),\n    interactions_endpoint_url: Option(String),\n    role_connections_verification_url: Option(String),\n    tags: Option(List(String)),\n    install_params: Option(InstallParams),\n    custom_install_url: Option(String),\n  )\n}\n Model for a Discord Application: https://discord.com/developers/docs/resources/application\n Note to self: summary is deprecated and will be removed in v11\nApplication(\n  id: Snowflake,\n  name: String,\n  icon: Option(String),\n  description: String,\n  rpc_origins: Option(List(String)),\n  bot_public: Bool,\n  bot_require_code_grant: Bool,\n  bot: Option(Bot),\n  terms_of_service_url: Option(String),\n  privacy_policy_url: Option(String),\n  owner: Option(Owner),\n  summary: Option(String),\n  verify_key: String,\n  team: Option(Team),\n  guild_id: Option(Snowflake),\n  primary_sku_id: Option(Snowflake),\n  slug: Option(String),\n  cover_image: Option(String),\n  flags: Option(Int),\n  approximate_guild_count: Option(Int),\n  redirect_uris: Option(List(String)),\n  interactions_endpoint_url: Option(String),\n  role_connections_verification_url: Option(String),\n  tags: Option(List(String)),\n  install_params: Option(InstallParams),\n  custom_install_url: Option(String),\n)\n\n\nSynonyms:\nglyph/models/discord.Application\nglyph/models/discord Application","url":"glyph/models/discord.html#Application"},{"doc":"glyph/models/discord","title":"Bot","content":"pub type Bot =\n  User\n\n\nSynonyms:\nglyph/models/discord.Bot\nglyph/models/discord Bot","url":"glyph/models/discord.html#Bot"},{"doc":"glyph/models/discord","title":"DiscordError","content":"pub type DiscordError\n Generic Discord Error\n\nSynonyms:\nglyph/models/discord.DiscordError\nglyph/models/discord DiscordError","url":"glyph/models/discord.html#DiscordError"},{"doc":"glyph/models/discord","title":"EventHandler","content":"pub type EventHandler {\n  EventHandler(\n    on_message_create: fn(Message) -&gt; Result(Nil, DiscordError),\n  )\n}\n\nEventHandler(\n  on_message_create: fn(Message) -&gt; Result(Nil, DiscordError),\n)\n\n\nSynonyms:\nglyph/models/discord.EventHandler\nglyph/models/discord EventHandler","url":"glyph/models/discord.html#EventHandler"},{"doc":"glyph/models/discord","title":"GatewayEvent","content":"pub type GatewayEvent {\n  GatewayEvent(\n    op: Int,\n    d: dynamic.Dynamic,\n    s: Option(Int),\n    t: Option(String),\n  )\n}\n Structure of payloads between gateway and client: https://discord.com/developers/docs/topics/gateway-events#payload-structure\nGatewayEvent(\n  op: Int,\n  d: dynamic.Dynamic,\n  s: Option(Int),\n  t: Option(String),\n)\n\n\nSynonyms:\nglyph/models/discord.GatewayEvent\nglyph/models/discord GatewayEvent","url":"glyph/models/discord.html#GatewayEvent"},{"doc":"glyph/models/discord","title":"GatewayIntent","content":"pub type GatewayIntent {\n  Guilds\n  GuildMembers\n  GuildModeration\n  GuildEmojisAndStickers\n  GuildIntegrations\n  GuildWebhooks\n  GuildInvites\n  GuildVoiceStates\n  GuildPresences\n  GuildMessages\n  GuildMessageReactions\n  GuildMessageTyping\n  DirectMessages\n  DirectMessageReactions\n  DirectMessageTyping\n  MessageContent\n  GuildScheduledEvents\n  AutoModerationConfiguration\n  AutoModerationExecution\n}\n The following are gateway intents which represent what events you subscribe to: https://discord.com/developers/docs/topics/gateway#gateway-intents\nGuilds\n\n\nGuildMembers\n\n\nGuildModeration\n\n\nGuildEmojisAndStickers\n\n\nGuildIntegrations\n\n\nGuildWebhooks\n\n\nGuildInvites\n\n\nGuildVoiceStates\n\n\nGuildPresences\n\n\nGuildMessages\n\n\nGuildMessageReactions\n\n\nGuildMessageTyping\n\n\nDirectMessages\n\n\nDirectMessageReactions\n\n\nDirectMessageTyping\n\n\nMessageContent\n\n\nGuildScheduledEvents\n\n\nAutoModerationConfiguration\n\n\nAutoModerationExecution\n\n\nSynonyms:\nglyph/models/discord.GatewayIntent\nglyph/models/discord GatewayIntent","url":"glyph/models/discord.html#GatewayIntent"},{"doc":"glyph/models/discord","title":"GetGatewayBot","content":"pub type GetGatewayBot {\n  GetGatewayBot(\n    url: String,\n    shards: Int,\n    session_start_limit: SessionStartLimit,\n  )\n}\n Model for Get Gateway Bot: https://discord.com/developers/docs/topics/gateway#get-gateway-bot\nGetGatewayBot(\n  url: String,\n  shards: Int,\n  session_start_limit: SessionStartLimit,\n)\n\n\nSynonyms:\nglyph/models/discord.GetGatewayBot\nglyph/models/discord GetGatewayBot","url":"glyph/models/discord.html#GetGatewayBot"},{"doc":"glyph/models/discord","title":"HelloEvent","content":"pub type HelloEvent {\n  HelloEvent(heartbeat_interval: Int)\n}\n Structure of a Hello event: https://discord.com/developers/docs/topics/gateway#hello-event\nHelloEvent(heartbeat_interval: Int)\n\n\nSynonyms:\nglyph/models/discord.HelloEvent\nglyph/models/discord HelloEvent","url":"glyph/models/discord.html#HelloEvent"},{"doc":"glyph/models/discord","title":"InstallParams","content":"pub type InstallParams {\n  InstallParams(scopes: List(String), permissions: String)\n}\n Model for Install Params: https://discord.com/developers/docs/resources/application#install-params-object\nInstallParams(scopes: List(String), permissions: String)\n\n\nSynonyms:\nglyph/models/discord.InstallParams\nglyph/models/discord InstallParams","url":"glyph/models/discord.html#InstallParams"},{"doc":"glyph/models/discord","title":"Member","content":"pub type Member {\n  Member(\n    membership_state: Int,\n    team_id: Snowflake,\n    user: User,\n    role: String,\n  )\n}\n Model for a Team Member object: https://discord.com/developers/docs/topics/teams#data-models-team-member-object\nMember(\n  membership_state: Int,\n  team_id: Snowflake,\n  user: User,\n  role: String,\n)\n\n\nSynonyms:\nglyph/models/discord.Member\nglyph/models/discord Member","url":"glyph/models/discord.html#Member"},{"doc":"glyph/models/discord","title":"MembershipState","content":"pub type MembershipState {\n  INVITED\n  ACCEPTED\n}\n Model for Membership State: https://discord.com/developers/docs/topics/teams#data-models-membership-state-enum\nINVITED\n\n\nACCEPTED\n\n\nSynonyms:\nglyph/models/discord.MembershipState\nglyph/models/discord MembershipState","url":"glyph/models/discord.html#MembershipState"},{"doc":"glyph/models/discord","title":"Message","content":"pub type Message {\n  Message(\n    id: Snowflake,\n    channel_id: Snowflake,\n    author: User,\n    content: String,\n    tts: Bool,\n    mention_everyone: Bool,\n    pinned: Bool,\n    message_type: Int,\n  )\n}\n Model for a Message object: https://discord.com/developers/docs/resources/channel#message-object\n TODO: add remaining fields\nMessage(\n  id: Snowflake,\n  channel_id: Snowflake,\n  author: User,\n  content: String,\n  tts: Bool,\n  mention_everyone: Bool,\n  pinned: Bool,\n  message_type: Int,\n)\n\n\nSynonyms:\nglyph/models/discord.Message\nglyph/models/discord Message","url":"glyph/models/discord.html#Message"},{"doc":"glyph/models/discord","title":"MessagePayload","content":"pub type MessagePayload {\n  MessagePayload(content: String)\n}\n Model for the payload when creating a message: https://discord.com/developers/docs/resources/channel#create-message\n TODO: add remaining fields\nMessagePayload(content: String)\n\n\nSynonyms:\nglyph/models/discord.MessagePayload\nglyph/models/discord MessagePayload","url":"glyph/models/discord.html#MessagePayload"},{"doc":"glyph/models/discord","title":"Owner","content":"pub type Owner =\n  User\n\n\nSynonyms:\nglyph/models/discord.Owner\nglyph/models/discord Owner","url":"glyph/models/discord.html#Owner"},{"doc":"glyph/models/discord","title":"ReadyApplication","content":"pub type ReadyApplication {\n  ReadyApplication(id: Snowflake, flags: Int)\n}\n Model for a partial Application received in the Ready event\nReadyApplication(id: Snowflake, flags: Int)\n\n\nSynonyms:\nglyph/models/discord.ReadyApplication\nglyph/models/discord ReadyApplication","url":"glyph/models/discord.html#ReadyApplication"},{"doc":"glyph/models/discord","title":"ReadyEvent","content":"pub type ReadyEvent {\n  ReadyEvent(\n    v: Int,\n    user: User,\n    guilds: dynamic.Dynamic,\n    session_id: String,\n    resume_gateway_url: String,\n    shard: Option(List(Int)),\n    application: ReadyApplication,\n  )\n}\n Structure of a Ready event: https://discord.com/developers/docs/topics/gateway-events#ready-ready-event-fields\nReadyEvent(\n  v: Int,\n  user: User,\n  guilds: dynamic.Dynamic,\n  session_id: String,\n  resume_gateway_url: String,\n  shard: Option(List(Int)),\n  application: ReadyApplication,\n)\n\n\nSynonyms:\nglyph/models/discord.ReadyEvent\nglyph/models/discord ReadyEvent","url":"glyph/models/discord.html#ReadyEvent"},{"doc":"glyph/models/discord","title":"SessionStartLimit","content":"pub type SessionStartLimit {\n  SessionStartLimit(\n    total: Int,\n    remaining: Int,\n    reset_after: Int,\n    max_concurrency: Int,\n  )\n}\n Model for Session Start Limit Object: https://discord.com/developers/docs/topics/gateway#session-start-limit-object\nSessionStartLimit(\n  total: Int,\n  remaining: Int,\n  reset_after: Int,\n  max_concurrency: Int,\n)\n\n\nSynonyms:\nglyph/models/discord.SessionStartLimit\nglyph/models/discord SessionStartLimit","url":"glyph/models/discord.html#SessionStartLimit"},{"doc":"glyph/models/discord","title":"Snowflake","content":"pub type Snowflake =\n  String\n The data structure Discord uses for UUIDs: https://discord.com/developers/docs/reference#snowflakes\n\nSynonyms:\nglyph/models/discord.Snowflake\nglyph/models/discord Snowflake","url":"glyph/models/discord.html#Snowflake"},{"doc":"glyph/models/discord","title":"Team","content":"pub type Team {\n  Team(\n    id: Snowflake,\n    icon: Option(String),\n    members: List(Member),\n    name: String,\n    owner_user_id: Snowflake,\n  )\n}\n Model for a Team object: https://discord.com/developers/docs/topics/teams#data-models-team-object\nTeam(\n  id: Snowflake,\n  icon: Option(String),\n  members: List(Member),\n  name: String,\n  owner_user_id: Snowflake,\n)\n\n\nSynonyms:\nglyph/models/discord.Team\nglyph/models/discord Team","url":"glyph/models/discord.html#Team"},{"doc":"glyph/models/discord","title":"User","content":"pub type User {\n  User(\n    id: Snowflake,\n    username: String,\n    discriminator: String,\n    global_name: Option(String),\n    avatar: Option(String),\n    bot: Option(Bool),\n    system: Option(Bool),\n    mfa_enabled: Option(Bool),\n    banner: Option(String),\n    accent_color: Option(Int),\n    locale: Option(String),\n    email: Option(String),\n    flags: Option(Int),\n    premium_type: Option(Int),\n    public_flags: Option(Int),\n    avatar_decoration: Option(String),\n  )\n}\n Model for a Discord User: https://discord.com/developers/docs/resources/user#user-object\n Some additional fields marked as optional here due to the use of partial user objects\n in other areas of the API.\nUser(\n  id: Snowflake,\n  username: String,\n  discriminator: String,\n  global_name: Option(String),\n  avatar: Option(String),\n  bot: Option(Bool),\n  system: Option(Bool),\n  mfa_enabled: Option(Bool),\n  banner: Option(String),\n  accent_color: Option(Int),\n  locale: Option(String),\n  email: Option(String),\n  flags: Option(Int),\n  premium_type: Option(Int),\n  public_flags: Option(Int),\n  avatar_decoration: Option(String),\n)\n\n\nSynonyms:\nglyph/models/discord.User\nglyph/models/discord User","url":"glyph/models/discord.html#User"},{"doc":"glyph/models/discord","title":"glyph/models/discord","content":" This contains all types needed to communicate with either the Gateway or REST API.","url":"glyph/models/discord.html"},{"doc":"glyph/models/decoders","title":"application_decoder","content":"pub fn application_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(Application, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.application_decoder\nglyph/models/decoders application_decoder","url":"glyph/models/decoders.html#application_decoder"},{"doc":"glyph/models/decoders","title":"gateway_event_decoder","content":"pub fn gateway_event_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(GatewayEvent, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.gateway_event_decoder\nglyph/models/decoders gateway_event_decoder","url":"glyph/models/decoders.html#gateway_event_decoder"},{"doc":"glyph/models/decoders","title":"gateway_hello_decoder","content":"pub fn gateway_hello_decoder(\n  dyn: Dynamic,\n) -&gt; Result(HelloEvent, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.gateway_hello_decoder\nglyph/models/decoders gateway_hello_decoder","url":"glyph/models/decoders.html#gateway_hello_decoder"},{"doc":"glyph/models/decoders","title":"gateway_partial_app_decoder","content":"pub fn gateway_partial_app_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(ReadyApplication, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.gateway_partial_app_decoder\nglyph/models/decoders gateway_partial_app_decoder","url":"glyph/models/decoders.html#gateway_partial_app_decoder"},{"doc":"glyph/models/decoders","title":"gateway_ready_decoder","content":"pub fn gateway_ready_decoder(\n  dyn: Dynamic,\n) -&gt; Result(ReadyEvent, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.gateway_ready_decoder\nglyph/models/decoders gateway_ready_decoder","url":"glyph/models/decoders.html#gateway_ready_decoder"},{"doc":"glyph/models/decoders","title":"get_gateway_bot_decoder","content":"pub fn get_gateway_bot_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(GetGatewayBot, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.get_gateway_bot_decoder\nglyph/models/decoders get_gateway_bot_decoder","url":"glyph/models/decoders.html#get_gateway_bot_decoder"},{"doc":"glyph/models/decoders","title":"install_params_decoder","content":"pub fn install_params_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(InstallParams, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.install_params_decoder\nglyph/models/decoders install_params_decoder","url":"glyph/models/decoders.html#install_params_decoder"},{"doc":"glyph/models/decoders","title":"member_decoder","content":"pub fn member_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(Member, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.member_decoder\nglyph/models/decoders member_decoder","url":"glyph/models/decoders.html#member_decoder"},{"doc":"glyph/models/decoders","title":"message_decoder","content":"pub fn message_decoder(\n  dyn: Dynamic,\n) -&gt; Result(Message, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.message_decoder\nglyph/models/decoders message_decoder","url":"glyph/models/decoders.html#message_decoder"},{"doc":"glyph/models/decoders","title":"session_start_limit_decoder","content":"pub fn session_start_limit_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(SessionStartLimit, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.session_start_limit_decoder\nglyph/models/decoders session_start_limit_decoder","url":"glyph/models/decoders.html#session_start_limit_decoder"},{"doc":"glyph/models/decoders","title":"team_decoder","content":"pub fn team_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(Team, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.team_decoder\nglyph/models/decoders team_decoder","url":"glyph/models/decoders.html#team_decoder"},{"doc":"glyph/models/decoders","title":"user_decoder","content":"pub fn user_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(User, List(DecodeError))\n\nSynonyms:\nglyph/models/decoders.user_decoder\nglyph/models/decoders user_decoder","url":"glyph/models/decoders.html#user_decoder"},{"doc":"glyph/models/decoders","title":"glyph/models/decoders","content":" This contains all decoders needed to parse responses into models.\n Adapted from Gleam&#39;s stdlib dynamic decoders.\n \n Abandon all hope, ye who enter.","url":"glyph/models/decoders.html"},{"doc":"glyph/models/encoders","title":"message_to_json","content":"pub fn message_to_json(message: MessagePayload) -&gt; String\n\nSynonyms:\nglyph/models/encoders.message_to_json\nglyph/models/encoders message_to_json","url":"glyph/models/encoders.html#message_to_json"},{"doc":"glyph/models/encoders","title":"glyph/models/encoders","content":" This contains all encoders needed to convert Discord payloads into JSON.","url":"glyph/models/encoders.html"},{"doc":"glyph/network/rest","title":"TokenType","content":"pub type TokenType {\n  Bearer\n  Bot\n}\n Acceptable values for an Authorization header\nBearer\n\n\nBot\n\n\nSynonyms:\nglyph/network/rest.TokenType\nglyph/network/rest TokenType","url":"glyph/network/rest.html#TokenType"},{"doc":"glyph/network/rest","title":"api_version","content":"pub const api_version: String = &quot;10&quot;\n\nSynonyms:\nglyph/network/rest.api_version\nglyph/network/rest api_version","url":"glyph/network/rest.html#api_version"},{"doc":"glyph/network/rest","title":"get","content":"pub fn get(\n  r: Request(String),\n  endpoint: String,\n) -&gt; Result(Response(String), Error)\n\nSynonyms:\nglyph/network/rest.get\nglyph/network/rest get","url":"glyph/network/rest.html#get"},{"doc":"glyph/network/rest","title":"new","content":"pub fn new() -&gt; Request(String)\n\nSynonyms:\nglyph/network/rest.new\nglyph/network/rest new","url":"glyph/network/rest.html#new"},{"doc":"glyph/network/rest","title":"post","content":"pub fn post(\n  r: Request(String),\n  endpoint: String,\n  body: String,\n) -&gt; Result(Response(String), Error)\n\nSynonyms:\nglyph/network/rest.post\nglyph/network/rest post","url":"glyph/network/rest.html#post"},{"doc":"glyph/network/rest","title":"set_authorization","content":"pub fn set_authorization(\n  r: Request(String),\n  token_type: TokenType,\n  token: String,\n) -&gt; Request(String)\n\nSynonyms:\nglyph/network/rest.set_authorization\nglyph/network/rest set_authorization","url":"glyph/network/rest.html#set_authorization"},{"doc":"glyph/network/rest","title":"set_bot_user_agent","content":"pub fn set_bot_user_agent(\n  r: Request(a),\n  url: String,\n  version: String,\n) -&gt; Request(a)\n\nSynonyms:\nglyph/network/rest.set_bot_user_agent\nglyph/network/rest set_bot_user_agent","url":"glyph/network/rest.html#set_bot_user_agent"},{"doc":"glyph/network/rest","title":"set_content_type","content":"pub fn set_content_type(\n  r: Request(String),\n  content_type: String,\n) -&gt; Request(String)\n\nSynonyms:\nglyph/network/rest.set_content_type\nglyph/network/rest set_content_type","url":"glyph/network/rest.html#set_content_type"},{"doc":"glyph/network/rest","title":"glyph/network/rest","content":" This handles the logic for communicating with the Discord REST API. For more information: https://discord.com/developers/docs/reference#http-api","url":"glyph/network/rest.html"},{"doc":"glyph/clients/api","title":"APIClient","content":"pub type APIClient {\n  APIClient(\n    token_type: rest.TokenType,\n    token: String,\n    client_url: String,\n    client_version: String,\n  )\n}\n\nAPIClient(\n  token_type: rest.TokenType,\n  token: String,\n  client_url: String,\n  client_version: String,\n)\n\n\nSynonyms:\nglyph/clients/api.APIClient\nglyph/clients/api APIClient","url":"glyph/clients/api.html#APIClient"},{"doc":"glyph/clients/api","title":"APIError","content":"pub type APIError {\n  HackneyError\n  DecodeError\n}\n\nHackneyError\n\n\nDecodeError\n\n\nSynonyms:\nglyph/clients/api.APIError\nglyph/clients/api APIError","url":"glyph/clients/api.html#APIError"},{"doc":"glyph/clients/api","title":"create_message","content":"pub fn create_message(\n  c: APIClient,\n  channel_id: String,\n  message: MessagePayload,\n) -&gt; Result(Nil, APIError)\n\nSynonyms:\nglyph/clients/api.create_message\nglyph/clients/api create_message","url":"glyph/clients/api.html#create_message"},{"doc":"glyph/clients/api","title":"get_application","content":"pub fn get_application(\n  c: APIClient,\n) -&gt; Result(Application, APIError)\n\nSynonyms:\nglyph/clients/api.get_application\nglyph/clients/api get_application","url":"glyph/clients/api.html#get_application"},{"doc":"glyph/clients/api","title":"get_gateway_bot","content":"pub fn get_gateway_bot(\n  c: APIClient,\n) -&gt; Result(GetGatewayBot, APIError)\n\nSynonyms:\nglyph/clients/api.get_gateway_bot\nglyph/clients/api get_gateway_bot","url":"glyph/clients/api.html#get_gateway_bot"},{"doc":"glyph/clients/api","title":"new","content":"pub fn new(\n  token: String,\n  client_url: String,\n  client_version: String,\n) -&gt; APIClient\n Construct a new APIClient\nSynonyms:\nglyph/clients/api.new\nglyph/clients/api new","url":"glyph/clients/api.html#new"},{"doc":"glyph/clients/api","title":"glyph/clients/api","content":" This contains the client for communicating with Discord&#39;s REST API.","url":"glyph/clients/api.html"},{"doc":"glyph/network/gateway","title":"ActorState","content":"pub type ActorState {\n  ActorState(\n    seq: Option(Int),\n    heartbeat_in_ms: Int,\n    self: process.Subject(Msg),\n    resume_gateway_url: String,\n    bot_id: discord.Snowflake,\n    handlers: discord.EventHandler,\n    received_hello: Bool,\n  )\n}\n\nActorState(\n  seq: Option(Int),\n  heartbeat_in_ms: Int,\n  self: process.Subject(Msg),\n  resume_gateway_url: String,\n  bot_id: discord.Snowflake,\n  handlers: discord.EventHandler,\n  received_hello: Bool,\n)\n\n\nSynonyms:\nglyph/network/gateway.ActorState\nglyph/network/gateway ActorState","url":"glyph/network/gateway.html#ActorState"},{"doc":"glyph/network/gateway","title":"GatewayError","content":"pub type GatewayError {\n  JsonError(json.DecodeError)\n  DynError(dynamic.DecodeError)\n  DynErrors(dynamic.DecodeErrors)\n}\n\nJsonError(json.DecodeError)\n\n\nDynError(dynamic.DecodeError)\n\n\nDynErrors(dynamic.DecodeErrors)\n\n\nSynonyms:\nglyph/network/gateway.GatewayError\nglyph/network/gateway GatewayError","url":"glyph/network/gateway.html#GatewayError"},{"doc":"glyph/network/gateway","title":"Msg","content":"pub type Msg {\n  Close\n  Heartbeat\n  Identify\n  Resume\n}\n\nClose\n\n\nHeartbeat\n\n\nIdentify\n\n\nResume\n\n\nSynonyms:\nglyph/network/gateway.Msg\nglyph/network/gateway Msg","url":"glyph/network/gateway.html#Msg"},{"doc":"glyph/network/gateway","title":"handle_gateway_recv","content":"pub fn handle_gateway_recv(\n  msg: String,\n  state: ActorState,\n  conn: Connection,\n) -&gt; ActorState\n This handles communicating with the gateway based on op codes: https://discord.com/developers/docs/topics/opcodes-and-status-codes#gateway-gateway-opcodes\nSynonyms:\nglyph/network/gateway.handle_gateway_recv\nglyph/network/gateway handle_gateway_recv","url":"glyph/network/gateway.html#handle_gateway_recv"},{"doc":"glyph/network/gateway","title":"start_ws_loop","content":"pub fn start_ws_loop(\n  discord_token: String,\n  intents: Int,\n  url: String,\n  event_handlers: EventHandler,\n) -&gt; a\n\nSynonyms:\nglyph/network/gateway.start_ws_loop\nglyph/network/gateway start_ws_loop","url":"glyph/network/gateway.html#start_ws_loop"},{"doc":"glyph/network/gateway","title":"glyph/network/gateway","content":" This handles the logic for communicating with the Discord Gateway API. For more information: https://discord.com/developers/docs/topics/gateway","url":"glyph/network/gateway.html"},{"doc":"glyph/clients/bot","title":"BotClient","content":"pub type BotClient {\n  BotClient(\n    token_type: rest.TokenType,\n    token: String,\n    client_url: String,\n    client_version: String,\n    intents: Int,\n    handlers: discord.EventHandler,\n    api_client: api.APIClient,\n  )\n}\n Type that contains necessary information when communicating with the Discord API\nBotClient(\n  token_type: rest.TokenType,\n  token: String,\n  client_url: String,\n  client_version: String,\n  intents: Int,\n  handlers: discord.EventHandler,\n  api_client: api.APIClient,\n)\n\n\nSynonyms:\nglyph/clients/bot.BotClient\nglyph/clients/bot BotClient","url":"glyph/clients/bot.html#BotClient"},{"doc":"glyph/clients/bot","title":"initialize","content":"pub fn initialize(b: BotClient) -&gt; a\n Initialize a client to begin communication with the gateway\nSynonyms:\nglyph/clients/bot.initialize\nglyph/clients/bot initialize","url":"glyph/clients/bot.html#initialize"},{"doc":"glyph/clients/bot","title":"new","content":"pub fn new(\n  token: String,\n  client_url: String,\n  client_version: String,\n) -&gt; BotClient\n Construct a new BotClient\nSynonyms:\nglyph/clients/bot.new\nglyph/clients/bot new","url":"glyph/clients/bot.html#new"},{"doc":"glyph/clients/bot","title":"on_message_create","content":"pub fn on_message_create(\n  b: BotClient,\n  callback: fn(Message) -&gt; Result(Nil, DiscordError),\n) -&gt; BotClient\n Register a handler for the MESSAGE_CREATE gateway event\nSynonyms:\nglyph/clients/bot.on_message_create\nglyph/clients/bot on_message_create","url":"glyph/clients/bot.html#on_message_create"},{"doc":"glyph/clients/bot","title":"send","content":"pub fn send(\n  b: BotClient,\n  channel_id: String,\n  message: String,\n) -&gt; Result(Nil, APIError)\n Send a message to a channel\nSynonyms:\nglyph/clients/bot.send\nglyph/clients/bot send","url":"glyph/clients/bot.html#send"},{"doc":"glyph/clients/bot","title":"set_intents","content":"pub fn set_intents(\n  b: BotClient,\n  intents: List(GatewayIntent),\n) -&gt; BotClient\n Register intents for your bot\nSynonyms:\nglyph/clients/bot.set_intents\nglyph/clients/bot set_intents","url":"glyph/clients/bot.html#set_intents"},{"doc":"glyph/clients/bot","title":"glyph/clients/bot","content":" This contains the client with functions specifically made for Bot users.","url":"glyph/clients/bot.html"}]);